feat_debug

Macro feat_debug 

macro_rules! feat_debug {
    ($feature:expr, $fmt:literal $(, $arg:expr)* $(,)?) => { ... };
}
Log a message at debug level for a feature. Only prints if the feature is enabled at debug level or higher.

feat_debug!("gc", "heap size: {}", size);